summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/grep.zsh4
1 files changed, 3 insertions, 1 deletions
diff --git a/lib/grep.zsh b/lib/grep.zsh
index 886e36a8d..bd9dad41f 100644
--- a/lib/grep.zsh
+++ b/lib/grep.zsh
@@ -19,8 +19,10 @@ elif grep-flag-available --exclude=.cvs; then
GREP_OPTIONS+=" --exclude=$EXC_FOLDERS"
fi
# export grep settings
alias grep="grep $GREP_OPTIONS"
+alias egrep="egrep $GREP_OPTIONS"
+alias fgrep="fgrep $GREP_OPTIONS"
# clean up
unset GREP_OPTIONS
@@ -19,8 +19,10 @@ elif grep-flag-available --exclude=.cvs; then
GREP_OPTIONS+=" --exclude=$EXC_FOLDERS"
fi
-# export grep settings
+# export grep, egrep and fgrep settings
alias grep="grep $GREP_OPTIONS"